package com.masilotti.hikingjournal.components

import android.view.Gravity
import android.view.ViewGroup
import androidx.appcompat.widget.Toolbar
import androidx.compose.material3.Button
import androidx.fragment.app.Fragment
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.platform.ComposeView
import com.masilotti.hikingjournal.R
import dev.hotwire.core.bridge.BridgeComponent
import dev.hotwire.core.bridge.BridgeDelegate
import dev.hotwire.core.bridge.Message
import dev.hotwire.navigation.destinations.HotwireDestination
import kotlinx.serialization.SerialName
import kotlinx.serialization.Serializable
// ...

class ButtonComponent(
    name: String,
    private val delegate: BridgeDelegate<HotwireDestination>
) : BridgeComponent<HotwireDestination>(name, delegate) {
    private val composeViewId = 1
    private val fragment: Fragment
        get() = delegate.destination.fragment

    override fun onReceive(message: Message) {
        val data = message.data<MessageData>() ?: return

        val composeView = ComposeView(fragment.requireContext()).apply {
            id = composeViewId
            setContent {
                ToolbarButton(
                    event = message.event,
                    title = data.title
                )
            }
        }
        val layoutParams = Toolbar.LayoutParams(
            ViewGroup.LayoutParams.WRAP_CONTENT,
            ViewGroup.LayoutParams.WRAP_CONTENT
        ).apply { gravity = Gravity.END }

        val toolbar = fragment.view?.findViewById<Toolbar>(R.id.toolbar)
        toolbar?.findViewById<ComposeView>(composeViewId)?.let {
            toolbar.removeView(it)
        }
        toolbar?.addView(composeView, layoutParams)
    }

    // ...
    @Composable
    fun ToolbarButton(event: String, title: String) {
        Button(
            onClick = { replyTo(event) }
        ) {
            Text(title)
        }
    }
}

@Serializable
data class MessageData(
    @SerialName("title") val title: String
)
